@@ -393,7 +393,9 @@ class Window:
         cDC.BitBlt((0, 0), (w, h), dcObj, region[0], win32con.SRCCOPY)
         bmpinfo = dataBitMap.GetInfo()
         bmpstr = dataBitMap.GetBitmapBits(True)
-        print(bmpstr)
+        return bmpstr, bmpinfo
+
+    def bitmap_to_image(self, bmpstr, bmpinfo):
         im = Image.frombuffer(
             'RGB',
             (bmpinfo['bmWidth'], bmpinfo['bmHeight']),
